@@ -1,4 +1,4 @@
-import main as egene
+import egene_main as egene
 import time
 
 # Calico Benchmarking
